@@ -3,14 +3,14 @@ package WHO::GrowthReference::GenChart;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-01-10'; # DATE
 our $DIST = 'WHO-GrowthReference-GenChart'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 
 use Exporter qw(import);
-our @EXPORT_OK = qw(gen_who_growth_chart_from_tsv);
+our @EXPORT_OK = qw(gen_who_growth_chart_from_table);
 
 our %SPEC;
 
@@ -365,7 +365,7 @@ WHO::GrowthReference::GenChart - Create WHO growth chart (weight/height/BMI)
 
 =head1 VERSION
 
-This document describes version 0.002 of WHO::GrowthReference::GenChart (from Perl distribution WHO-GrowthReference-GenChart), released on 2021-01-10.
+This document describes version 0.003 of WHO::GrowthReference::GenChart (from Perl distribution WHO-GrowthReference-GenChart), released on 2021-01-10.
 
 =head1 SYNOPSIS
 
@@ -401,7 +401,7 @@ Usage:
 
 Create WHO growth chart (weightE<sol>heightE<sol>BMI).
 
-This function is not exported.
+This function is not exported by default, but exportable.
 
 Arguments ('*' denotes required arguments):
 
